package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Aug 6, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type URLParam struct {
URL string `form:"url" json:"url" binding:"required"`
}
type URLResp struct {
TinyURL string `json:"tinyurl"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.