package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Aug 6, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type TinyURL struct {
ID uint64 `gorm:"column:id" json:"id"`
URL string `gorm:"column:url" json:"url"`
}
域名的解析规则
Source Files
¶
Click to show internal directories.
Click to hide internal directories.